#!/bin/bash
#SBATCH --partition=slim18              # (queue, see sinfo) 
#SBATCH --ntasks=16                     # number of threads
#SBATCH --mem 128G                      #memory pool for all cores 
#SBATCH -o slurm.%u.%j.out              #STDOUT 
#SBATCH -e slurm.%u.%j.err              #STDERR


##Requirements##

module load ngs/minimap2/2.10
module load ngs/bwa/0.7.16
module load ngs/samtools/1.8
module load python/3.6
module load ngs/freebayes/1.2.0
module load ngs/bedtools2/2.26.0

main(){
	set_variables
	create_folders
#	minimap2_index_genome
#	mapping_corrected_smrt_reads_to_genome
#	bwa_index_genome
#	single_end_read_alignment
#	paired_end_read_alignment
#	freebayes_prepare
#	freebayes_run
#	freebayes_merge
#	filter_vcf_file

#	generate_bed_count_files
#	gc_content


}

set_variables(){
	INPUT_FOLDER=input
	OUTPUT_FOLDER=output
	SCRIPTS_FOLDER=bin
	READ_FOLDER=$INPUT_FOLDER/reads
	RNASEQ_READ_FOLDER=$READ_FOLDER/RNAseq
	H3V_COHESIN_CHIP_READ_FOLDER=$READ_FOLDER/H3V_Cohesin_ChIP
	BASEJ_READ_FOLDER=$READ_FOLDER/BaseJ

	GENOME_FILE=HGAP3_Tb427v10.fasta
	MINIMAP2_INDEX_FOLDER=${OUTPUT_FOLDER}/mm2_indexes
	BWA_INDEX_FOLDER=${OUTPUT_FOLDER}/bwa_indexes

	ALIGNMENT_FOLDER=${OUTPUT_FOLDER}/alignment
	REMOVE_DUP_METRICS_FOLDER=${ALIGNMENT_FOLDER}/rmdup_metrics
	BED_FOLDER=$OUTPUT_FOLDER/bed_folder
	PICARD=~/picard.jar
        FREEBAYES_OUTPUT_FOLDER=$OUTPUT_FOLDER/freebayes
        FREEBAYES_SPLIT_GENOME_FOLDER=$FREEBAYES_OUTPUT_FOLDER/split_genome
        FREEBAYES_VCF_BY_REGION_FOLDER=$FREEBAYES_OUTPUT_FOLDER/vcf_by_region

        VCFSTREAMSORT="/opt/software/ngs/freebayes-1.2.0/vcflib/bin/vcfstreamsort"
        VCFUNIQUE="/opt/software/ngs/freebayes-1.2.0/vcflib/bin/vcfuniq"
        VCFSTATS="/opt/software/ngs/freebayes-1.2.0/vcflib/bin/vcfstats"
        VCFFILTER="/opt/software/ngs/freebayes-1.2.0/vcflib/bin/vcffilter"
        VCFINTERSECT="/opt/software/ngs/freebayes-1.2.0/vcflib/bin/vcfintersect"



}

create_folders(){
mkdir -p \
	$SCRIPTS_FOLDER \
	$INPUT_FOLDER \
	$OUTPUT_FOLDER \
	$READ_FOLDER \
	$RNASEQ_READ_FOLDER \
	$H3V_COHESIN_CHIP_READ_FOLDER \
	$BASEJ_READ_FOLDER \
	$MINIMAP2_INDEX_FOLDER \
	$BWA_INDEX_FOLDER \
	$ALIGNMENT_FOLDER \
	$REMOVE_DUP_METRICS_FOLDER \
	$FREEBAYES_OUTPUT_FOLDER \
	$FREEBAYES_SPLIT_GENOME_FOLDER \
	$FREEBAYES_VCF_BY_REGION_FOLDER \
	$BED_FOLDER
}


minimap2_index_genome(){
# mmp2 Index the Tb427v10 genome

GENOME_FASTA=${INPUT_FOLDER}/${GENOME_FILE}
GENOME_INDEX=${MINIMAP2_INDEX_FOLDER}/${GENOME_FILE%.fasta}.mmi

	jid1=$(sbatch --job-name=mmp2_ix --wrap="minimap2 -d ${GENOME_INDEX} ${GENOME_FASTA}")
	jid1=$(echo $jid1 | sed "s/Submitted batch job //")

}

mapping_corrected_smrt_reads_to_genome(){
# Map the corrected SMRT reads to the Tb427v10  genome

GENOME_INDEX=${GENOME_FILE%.fasta}.mmi
READS=corrected.untrimmed.fq.gz

	jid2=$(sbatch --job-name=mmp2_mapping --export=READS=${READS},READS_FOLDER=${READ_FOLDER},MINIMAP2_INDEX_FOLDER=${MINIMAP2_INDEX_FOLDER},GENOME_INDEX=${GENOME_INDEX},MINIMAP2_ALIGNMENT_FOLDER=${ALIGNMENT_FOLDER} ${SCRIPTS_FOLDER}/mmp2_corrected_smrt_reads.sh)
	jid2=$(echo $jid2 | sed "s/Submitted batch job //")
} # Takes ~20 min in the cluster



bwa_index_genome(){
    
	jid3=$(sbatch --job-name=bwa_ix --wrap="bwa index -p $BWA_INDEX_FOLDER/$GENOME_FILE $INPUT_FOLDER/$GENOME_FILE")
	jid3=$(echo $jid3 | sed "s/Submitted batch job //")
}


single_end_read_alignment(){


#single-end BSF NS053 data mapping
for INPUT_FILE_READ in ID-001714_BF_control_NS053.fq.bz2 
        do
        PREFIX=${INPUT_FILE_READ%.fq.bz2}
        OUTPUT_BAM=${ALIGNMENT_FOLDER}/${PREFIX}"_to_"${GENOME_FILE%.fasta}"_bwa.bam"
        INPUT_FILE_READ=${READ_FOLDER}/${INPUT_FILE_READ}
        GENOME_INDEX=${BWA_INDEX_FOLDER}/${GENOME_FILE}

        jid4=$(sbatch --job-name=se_aln --export=GENOME_INDEX=${GENOME_INDEX},INPUT_FILE_READ=${INPUT_FILE_READ},OUTPUT_FILE=${OUTPUT_BAM},PICARD=${PICARD},REMOVE_DUP_METRICS_FOLDER=${REMOVE_DUP_METRICS_FOLDER} ${SCRIPTS_FOLDER}/run_alignment.sh)
	jid4=$(echo $jid4 | sed "s/Submitted batch job //")

        done


#Base J data data mapping

for INPUT_FILE_READ in $(ls $BASEJ_READ_FOLDER | grep "fq.gz$\|fq.bz2$\|fastq.gz$")
        do
        PREFIX=${INPUT_FILE_READ%.fq.gz}
        OUTPUT_BAM=${ALIGNMENT_FOLDER}/${PREFIX}"_to_"${GENOME_FILE%.fasta}"_bwa.bam"
        INPUT_FILE_READ=${BASEJ_READ_FOLDER}/${INPUT_FILE_READ}
        GENOME_INDEX=${BWA_INDEX_FOLDER}/${GENOME_FILE}

        jid5=$(sbatch --job-name=se_aln --export=GENOME_INDEX=${GENOME_INDEX},INPUT_FILE_READ=${INPUT_FILE_READ},OUTPUT_FILE=${OUTPUT_BAM},PICARD=${PICARD},REMOVE_DUP_METRICS_FOLDER=${REMOVE_DUP_METRICS_FOLDER} ${SCRIPTS_FOLDER}/run_alignment.sh)
	jid5=$(echo $jid5 | sed "s/Submitted batch job //")

        done



jid6=$(sbatch --job-name=se_aln --dependency=singleton --wrap="echo Single-end alignment step finished.")
jid6=$(echo $jid6 | sed "s/Submitted batch job //")


}

paired_end_read_alignment(){

for INPUT_FILE_READ_1 in $(ls $READ_FOLDER | grep "fq.gz$\|fq.bz2$\|fastq.gz$" | grep _R1)
        do
        PREFIX=${INPUT_FILE_READ_1%_R1.*}
        OUTPUT_BAM=${ALIGNMENT_FOLDER}/${PREFIX}"_to_"${GENOME_FILE%.fasta}"_bwa.bam"
        INPUT_FILE_READ_1=${READ_FOLDER}/${INPUT_FILE_READ_1}
        INPUT_FILE_READ_2=$(echo $INPUT_FILE_READ_1 | sed "s/_R1/_R2/")
        GENOME_INDEX=${BWA_INDEX_FOLDER}/${GENOME_FILE}

        jid7=$(sbatch --job-name=pe_aln --export=GENOME_INDEX=${GENOME_INDEX},INPUT_FILE_READ_1=${INPUT_FILE_READ_1},INPUT_FILE_READ_2=${INPUT_FILE_READ_2},OUTPUT_FILE=${OUTPUT_BAM},PICARD=${PICARD},REMOVE_DUP_METRICS_FOLDER=${REMOVE_DUP_METRICS_FOLDER} ${SCRIPTS_FOLDER}/run_paired_end_alignment.sh)
        jid7=$(echo $jid7 | sed "s/Submitted batch job //")

        done



#Mueller et al. H3.V and Cohesin ChIP data alignment
for INPUT_FILE_READ_1 in $(ls $H3V_COHESIN_CHIP_READ_FOLDER | grep "fq.gz$\|fq.bz2$\|fastq.gz$" | grep _R1)
        do
        PREFIX=${INPUT_FILE_READ_1%_R1.*}
        OUTPUT_BAM=${ALIGNMENT_FOLDER}/${PREFIX}"_to_"${GENOME_FILE%.fasta}"_bwa.bam"
        INPUT_FILE_READ_1=${H3V_COHESIN_CHIP_READ_FOLDER}/${INPUT_FILE_READ_1}
        INPUT_FILE_READ_2=$(echo $INPUT_FILE_READ_1 | sed "s/_R1/_R2/")
        GENOME_INDEX=${BWA_INDEX_FOLDER}/${GENOME_FILE}

        jid8=$(sbatch --job-name=pe_aln --export=GENOME_INDEX=${GENOME_INDEX},INPUT_FILE_READ_1=${INPUT_FILE_READ_1},INPUT_FILE_READ_2=${INPUT_FILE_READ_2},OUTPUT_FILE=${OUTPUT_BAM},PICARD=${PICARD},REMOVE_DUP_METRICS_FOLDER=${REMOVE_DUP_METRICS_FOLDER} ${SCRIPTS_FOLDER}/run_paired_end_alignment.sh)
        jid8=$(echo $jid8 | sed "s/Submitted batch job //")

        done


#RNA-seq data alignment
for INPUT_FILE_READ_1 in $(ls $RNASEQ_READ_FOLDER | grep "fq.gz$\|fq.bz2$\|fastq.gz$" | grep _R1)
        do
        PREFIX=${INPUT_FILE_READ_1%_R1.*}
        OUTPUT_BAM=${ALIGNMENT_FOLDER}/${PREFIX}"_to_"${GENOME_FILE%.fasta}"_bwa.bam"
        INPUT_FILE_READ_1=${RNASEQ_READ_FOLDER}/${INPUT_FILE_READ_1}
        INPUT_FILE_READ_2=$(echo $INPUT_FILE_READ_1 | sed "s/_R1/_R2/")
        GENOME_INDEX=${BWA_INDEX_FOLDER}/${GENOME_FILE}

        jid9=$(sbatch --job-name=pe_aln --export=GENOME_INDEX=${GENOME_INDEX},INPUT_FILE_READ_1=${INPUT_FILE_READ_1},INPUT_FILE_READ_2=${INPUT_FILE_READ_2},OUTPUT_FILE=${OUTPUT_BAM},PICARD=${PICARD},REMOVE_DUP_METRICS_FOLDER=${REMOVE_DUP_METRICS_FOLDER} ${SCRIPTS_FOLDER}/run_paired_end_alignment.sh)
        jid9=$(echo $jid9 | sed "s/Submitted batch job //")

        done

jid10=$(sbatch --job-name=pe_aln --dependency=singleton --wrap="echo Paired-end alignment step finished.")
jid10=$(echo $jid10 | sed "s/Submitted batch job //")

}

freebayes_prepare(){

## Split the genomes into 100Kb fragments to run freebayes in parallel
for GENOME in $GENOME_FILE
do
        jid11=$(sbatch --job-name=faidx --wrap="samtools faidx ${INPUT_FOLDER}/${GENOME}")
        jid11=$(echo $jid11 | sed "s/Submitted batch job //")

        jid12=$(sbatch --job-name=mv_faidx --dependency=afterok:${jid11} --wrap="mv ${INPUT_FOLDER}/${GENOME}.fai ${FREEBAYES_SPLIT_GENOME_FOLDER}")
        jid12=$(echo $jid12 | sed "s/Submitted batch job //")

        jid13=$(sbatch --job-name=regions --dependency=afterok:${jid12} --wrap="python3.6 ${SCRIPTS_FOLDER}/fasta_generate_regions.py ${FREEBAYES_SPLIT_GENOME_FOLDER}/${GENOME}.fai 100000 > ${FREEBAYES_SPLIT_GENOME_FOLDER}/${GENOME}.100kb.fragments")
        jid13=$(echo $jid13 | sed "s/Submitted batch job //")
done
}

freebayes_run(){
## Generate VCF file for each region for the short-read DNA-seq datasets.

while read PREFIX
do
	for BAM in $(ls $ALIGNMENT_FOLDER | grep "^${PREFIX}" | grep "rmdup.sorted.bam$")
	do
		for REGION in $(cat ${FREEBAYES_SPLIT_GENOME_FOLDER}/${GENOME_FILE}.100kb.fragments)
		do
		INPUT_BAM=${ALIGNMENT_FOLDER}/${BAM}
		OUTPUT_VCF=${FREEBAYES_VCF_BY_REGION_FOLDER}/var_${BAM%.rmdup.sorted.bam}_${REGION}_region.vcf

		jid14=$(sbatch --job-name=freebayes --mem=10G --wrap="freebayes -f ${INPUT_FOLDER}/${GENOME_FILE} --region ${REGION} ${INPUT_BAM} > ${OUTPUT_VCF}")
		jid14=$(echo $jid14 | sed "s/Submitted batch job //")
		done

	done
done < $INPUT_FOLDER/variant_density_list.txt



## Generate VCF file for each region for the corrected PacBio reads

for BAM in $(ls ${ALIGNMENT_FOLDER} |  grep '^corrected.untrimmed' | grep 'sorted.mapq10.F2308.bam$')
do
	for REGION in $(cat ${FREEBAYES_SPLIT_GENOME_FOLDER}/${GENOME_FILE}.100kb.fragments)
	do
		INPUT_BAM=${ALIGNMENT_FOLDER}/${BAM}
		OUTPUT_VCF=${FREEBAYES_VCF_BY_REGION_FOLDER}/var_${BAM%sorted.map10.F2308.bam}_${i}_region.vcf
		jid15=$(sbatch --job-name=freebayes --mem=10G --wrap="freebayes -f ${INPUT_FOLDER}/${GENOME_FILE} --region ${REGION} ${INPUT_BAM} > ${OUTPUT_VCF}")
		jid15=$(echo $jid15 | sed "s/Submitted batch job //")
		

	done

done # ran in the cluster took:~2hs most of it, ~4hs there is still one region remaining.It finished after ~8hs in total.

jid16=$(sbatch --job-name=freebayes --dependency=singleton --wrap="echo VCF files generation by freebayes finished")
jid16=$(echo $jid16 | sed "s/Submitted batch job //")


}

freebayes_merge(){

# Merge vcf files of the regions for the short-reads
while read PREFIX
do
       for BAM in $(ls $ALIGNMENT_FOLDER | grep "^${PREFIX}" | grep "rmdup.sorted.bam$")
       do
               # Name of the output file containing the merged vcf of the regions:
               MERGED_VCF=${FREEBAYES_OUTPUT_FOLDER}/var_${BAM%.rmdup.sorted.bam}_all.vcf
               BAM_GREP=${BAM%.rmdup.sorted.bam}

               # Merge the vcf files
               jid17=$(sbatch --job-name=join_vcf --export=MERGED_VCF=${MERGED_VCF},FREEBAYES_VCF_BY_REGION_FOLDER=${FREEBAYES_VCF_BY_REGION_FOLDER},GENOME=${GENOME_FILE},BAM_GREP=${BAM_GREP},SCRIPTS_FOLDER=${SCRIPTS_FOLDER},VCFSTREAMSORT=${VCFSTREAMSORT},VCFUNIQUE=${VCFUNIQUE} ${SCRIPTS_FOLDER}/merge_vcfs_by_region.sh)
               jid17=$(echo $jid17 | sed "s/Submitted batch job //")

       done
done < $INPUT_FOLDER/variant_density_list.txt


# Merge vcf files of the regions for the corrected PacBio reads
for BAM in $(ls ${ALIGNMENT_FOLDER} |  grep '^corrected.untrimmed' | grep 'sorted.mapq10.F2308.bam$')
do

	MERGED_VCF=${FREEBAYES_OUTPUT_FOLDER}/var_${BAM%.sorted.mapq10.F2308.bam}_all.vcf
	BAM_GREP=${BAM%.sorted.mapq10.F2308.bam}


	# Merge the vcf files
	jid18=$(sbatch --job-name=join_vcf --export=MERGED_VCF=${MERGED_VCF},FREEBAYES_VCF_BY_REGION_FOLDER=${FREEBAYES_VCF_BY_REGION_FOLDER},GENOME=${GENOME_FILE},BAM_GREP=${BAM_GREP},SCRIPTS_FOLDER=${SCRIPTS_FOLDER},VCFSTREAMSORT=${VCFSTREAMSORT},VCFUNIQUE=${VCFUNIQUE} ${SCRIPTS_FOLDER}/merge_vcfs_by_region.sh)
	jid18=$(echo $jid18 | sed "s/Submitted batch job //")

done


}

filter_vcf_file(){

## Filtering vcf file of short read gDNA-seq
for VCF in $(ls $FREEBAYES_OUTPUT_FOLDER | grep '_all.vcf$' | grep -v 'corrected.untrimmed')
do
	# Name of the input file containing the merged vcf of the regions:
	MERGED_VCF=${FREEBAYES_OUTPUT_FOLDER}/${VCF}
	jid19=$(sbatch --job-name=filter_vcf --wrap="${VCFFILTER} -s -f ' QUAL > 20' ${MERGED_VCF} > ${MERGED_VCF%.vcf}.q20.vcf")
	jid19=$(echo $jid19 | sed "s/Submitted batch job //")
done



## Filtering vcf file of the corrected PacBio reads

for VCF in $(ls $FREEBAYES_OUTPUT_FOLDER | grep '_all.vcf$' | grep 'corrected.untrimmed')
do
	# Name of the input file containing the merged vcf of the regions:
	MERGED_VCF=${FREEBAYES_OUTPUT_FOLDER}/${VCF}
	jid20=$(sbatch --job-name=filter_vcf --wrap="${VCFFILTER} -s -f 'DP > 10 & QUAL > 20' ${MERGED_VCF} > ${MERGED_VCF%.vcf}.q20.dp10.vcf")
	jid20=$(echo $jid20 | sed "s/Submitted batch job //")

done

jid21=$(sbatch --job-name=filter_vcf --dependency=singleton --wrap="echo VCF quality filtering finished")
jid21=$(echo $jid21 | sed "s/Submitted batch job //")

## Remove those variants that contain N in the reference allele:

# Remove for short-read derived vcfs
for VCF in $(ls $FREEBAYES_OUTPUT_FOLDER | grep '_all.vcf$' | grep -v 'corrected.untrimmed')
do
      MERGED_VCF=${FREEBAYES_OUTPUT_FOLDER}/${VCF%.vcf}.q20.vcf
      jid22=$(sbatch --job-name=rm_Ns_vcf --dependency=afterok:${jid21} --wrap="grep -Pv '\tN*\t' ${MERGED_VCF} > ${MERGED_VCF%.vcf}.Ns_removed.vcf")
      jid22=$(echo $jid22 | sed "s/Submitted batch job //")
done

# Remove for PacBio derived vcf
for VCF in $(ls $FREEBAYES_OUTPUT_FOLDER |  grep '_all.vcf$'| grep 'corrected.untrimmed')
do
       MERGED_VCF=${FREEBAYES_OUTPUT_FOLDER}/${VCF%.vcf}.q20.dp10.vcf
       jid23=$(sbatch --job-name=rm_Ns_vcf --dependency=afterok:${jid21} --wrap="grep -Pv '\tN*\t' ${MERGED_VCF} > ${MERGED_VCF%.vcf}.Ns_removed.vcf")
       jid23=$(echo $jid23 | sed "s/Submitted batch job //")
done

jid24=$(sbatch --job-name=rm_Ns_vcf --dependency=singleton --wrap="echo Removal of VCF entries overlapping Ns finished")
jid24=$(echo $jid24 | sed "s/Submitted batch job //")



## Keep only the heterozygote variants (0/1 or 1/2) --> Variants between the alleles

# For short-read derived vcfs
for VCF in $(ls $FREEBAYES_OUTPUT_FOLDER | grep '_all.vcf$' | grep -v 'corrected.untrimmed')
do
	VCF=${FREEBAYES_OUTPUT_FOLDER}/${VCF%.vcf}.q20.Ns_removed.vcf
	jid25=$(sbatch --job-name=filter_var_type --dependency=afterok:${jid24} --wrap="grep '^#' ${VCF} > ${VCF%.vcf}.het.vcf")
	jid25=$(echo $jid25 | sed "s/Submitted batch job //")


       jid26=$(sbatch --job-name=filter_var_type --dependency=afterok:${jid25} --wrap="grep '0/1:\|1/2' ${VCF} >> ${VCF%.vcf}.het.vcf")
       jid26=$(echo $jid26 | sed "s/Submitted batch job //")


done

# For PacBio derived vcf
for VCF in $(ls $FREEBAYES_OUTPUT_FOLDER | grep '_all.vcf$' | grep 'corrected.untrimmed')
do
	VCF=${FREEBAYES_OUTPUT_FOLDER}/${VCF%.vcf}.q20.dp10.Ns_removed.vcf
	jid27=$(sbatch --job-name=filter_var_type --dependency=afterok:${jid24} --wrap="grep '^#' ${VCF} > ${VCF%.vcf}.het.vcf")
	jid27=$(echo $jid27 | sed "s/Submitted batch job //")


       jid28=$(sbatch --job-name=filter_var_type --dependency=afterok:${jid27} --wrap="grep '0/1:\|1/2' ${VCF} >> ${VCF%.vcf}.het.vcf")
       jid28=$(echo $jid28 | sed "s/Submitted batch job //")


done

jid29=$(sbatch --job-name=filter_var_type --dependency=singleton --wrap="echo heterozygote variants filtering of VCF files finished")
jid29=$(echo $jid29 | sed "s/Submitted batch job //")

### Filter PacBio vcf heterozygote vcf by snps(+mnps), INDELS or complex

#for VCF in var_corrected.untrimmed_to_HGAP3_Tb427v9.9_without_allelic_variants_all.q20.dp10.Ns_removed.het.vcf
for VCF in $(ls $FREEBAYES_OUTPUT_FOLDER | grep '_all.vcf$' | grep 'corrected.untrimmed')
do
	VCF=${FREEBAYES_OUTPUT_FOLDER}/${VCF%.vcf}.q20.dp10.Ns_removed.het.vcf


        jid30=$(sbatch --job-name=filsnps --dependency=afterok:${jid29} --wrap="grep '^#\|^Chr.*_core_' ${VCF} | grep '^#\|TYPE=snp\|TYPE=mnp' > ${VCF%.vcf}.core_snps.vcf")
        jid30=$(echo $jid29 | sed "s/Submitted batch job //")

        jid31=$(sbatch --job-name=filINDEL --dependency=afterok:${jid29} --wrap="grep '^#\|^Chr.*_core_' ${VCF} | grep '^#\|TYPE=ins\|TYPE=del' > ${VCF%.vcf}.core_INDELs.vcf")
        jid31=$(echo $jid31 | sed "s/Submitted batch job //")

        jid32=$(sbatch --job-name=filcomplex --dependency=afterok:${jid29} --wrap="grep '^#\|^Chr.*_core_' ${VCF} | grep '^#\|TYPE=complex' > ${VCF%.vcf}.core_complex.vcf")
        jid32=$(echo $jid32 | sed "s/Submitted batch job //")


done


}

generate_bed_count_files(){


# Generate a file with genome sizes
jid33=$(sbatch --job-name=chr_lengths --wrap="python ${SCRIPTS_FOLDER}/seq_length.py $INPUT_FOLDER/$GENOME_FILE > ${BED_FOLDER}/${GENOME_FILE%.fasta}.sizes")
jid33=$(echo $jid33 | sed "s/Submitted batch job //")

# Generate bins with bedtools, 10Kb bins, 1Kb sliding window
jid34=$(sbatch --job-name=bin_genome --dependency=afterok:${jid33} --wrap="bedtools makewindows -g ${BED_FOLDER}/${GENOME_FILE%.fasta}.sizes -w 10000 -s 1000 > ${BED_FOLDER}/${GENOME_FILE%.fasta}.10Kb_bins.bed")
jid34=$(echo $jid34 | sed "s/Submitted batch job //")

## Count variants per bin using bedtools coverage

for VCF in $(ls $FREEBAYES_OUTPUT_FOLDER | grep 'Ns_removed.het.vcf$')
do
	jid35=$(sbatch --job-name=variant_cov --dependency=afterok:${jid34} --mem=128g --wrap="bedtools coverage -a ${BED_FOLDER}/${GENOME_FILE%.fasta}.10Kb_bins.bed -b ${FREEBAYES_OUTPUT_FOLDER}/${VCF} -counts > ${BED_FOLDER}/${VCF%.vcf}.var_density.txt")
	jid35=$(echo $jid31 | sed "s/Submitted batch job //")
done


# Count reads per bin using bedtools coverage
for BAM in $(ls ${ALIGNMENT_FOLDER} | grep 'rmdup.sorted.bam$')
do
	
	jid36=$(sbatch --job-name=bam_cov --dependency=afterok:${jid34} --mem=128g --wrap="bedtools coverage -a ${BED_FOLDER}/${GENOME_FILE%.fasta}.10Kb_bins.bed -b ${ALIGNMENT_FOLDER}/${BAM} -counts > ${BED_FOLDER}/${BAM%.rmdup.sorted.bam}_density.txt")
	jid36=$(echo $jid36 | sed "s/Submitted batch job //")

done

# Count reads per bin using bedtools coverage for the PacBio corrected reads
for BAM in $(ls ${ALIGNMENT_FOLDER} | grep '^corrected.untrimmed' | grep 'sorted.bam$')
do

	jid37=$(sbatch --job-name=bam_cov --dependency=afterok:${jid34} --mem=128g --wrap="bedtools coverage -a ${BED_FOLDER}/${GENOME_FILE%.fasta}.10Kb_bins.bed -b ${ALIGNMENT_FOLDER}/${BAM} -counts > ${BED_FOLDER}/${BAM%.sorted.bam}_density.txt")
	jid37=$(echo $jid37 | sed "s/Submitted batch job //")

done

# Count reads per bin using bedtools coverage for the filtered bams to calculate mappability

for BAM in $(ls ${ALIGNMENT_FOLDER} | grep '.rmdup.sorted.mapq10.bam$')
do
	
	jid38=$(sbatch --job-name=bam_cov --dependency=afterok:${jid34} --mem=128g --wrap="bedtools coverage -a ${BED_FOLDER}/${GENOME_FILE%.fasta}.10Kb_bins.bed -b ${ALIGNMENT_FOLDER}/${BAM} -counts > ${BED_FOLDER}/${BAM%.rmdup.sorted.mapq10.bam}_density_mapq10.txt")
	jid38=$(echo $jid38 | sed "s/Submitted batch job //")

done

# Count reads per bin using bedtools coverage for the PacBio filtered bam to calculate mappability

for BAM in $(ls ${ALIGNMENT_FOLDER} |  grep '^corrected.untrimmed' | grep 'sorted.mapq10.F2308.bam$')
do
	
	jid39=$(sbatch --job-name=bam_cov --dependency=afterok:${jid34} --mem=128g --wrap="bedtools coverage -a ${BED_FOLDER}/${GENOME_FILE%.fasta}.10Kb_bins.bed -b ${ALIGNMENT_FOLDER}/${BAM} -counts > ${BED_FOLDER}/${BAM%.sorted.mapq10.F2308.bam}_density_mapq10.txt")
	jid39=$(echo $jid39 | sed "s/Submitted batch job //")

done


jid40=$(sbatch --job-name=bam_cov --dependency=singleton --wrap="echo bedtools coverage from bam files finished.")
jid40=$(echo $jid40 | sed "s/Submitted batch job //")

# Generate ratio bed files for the ChIP-seq data
while read NUM DEN OUT_PREFIX
do
	jid41=$(sbatch --job-name=bed_ratio --dependency=afterok:${jid40} --export=NUM=${NUM},DEN=${DEN},OUT_PREFIX=${OUT_PREFIX},BED_FOLDER=${BED_FOLDER}, ${SCRIPTS_FOLDER}/ratio_bed.sh)
	jid42=$(echo $jid43 | sed "s/Submitted batch job //")

done < $INPUT_FOLDER/ratio_list.txt

# Generate ratio bed files for mappability assessment
while read SAMPLE OUT_PREFIX
do
	jid44=$(sbatch --job-name=bed_map --dependency=afterok:${jid40} --export=SAMPLE=${SAMPLE},OUT_PREFIX=${OUT_PREFIX},BED_FOLDER=${BED_FOLDER}, ${SCRIPTS_FOLDER}/ratio_bed_mappability.sh)
	jid44=$(echo $jid44 | sed "s/Submitted batch job //")

done < $INPUT_FOLDER/mappability_list.txt

#Count unphased variants per bin using bedtools coverage

UNPHASED_FILE=Unphased_variants_coordinates_v10.txt

jid45=$(sbatch --job-name=unphased_var_cov --dependency=afterok:${jid34} --wrap="bedtools coverage -a ${BED_FOLDER}/${GENOME_FILE%.fasta}.10Kb_bins.bed -b ${INPUT_FOLDER}/${UNPHASED_FILE} -counts > ${BED_FOLDER}/${UNPHASED_FILE%_v10.txt}.var_density.txt")
jid45=$(echo $jid45 | sed "s/Submitted batch job //")

#Count heterozygote variants in the corrected genome version divided by type

for VCF in $(ls $FREEBAYES_OUTPUT_FOLDER | grep 'Ns_removed.het.vcf$' | grep 'corrected.untrimmed')
do
	for SUBSET in ${VCF%.vcf}.core_snps.vcf ${VCF%.vcf}.core_INDELs.vcf ${VCF%.vcf}.core_complex.vcf
	do
        	jid46=$(sbatch --job-name=PacBio_types_var_cov --dependency=afterok:${jid34} --wrap="bedtools coverage -a ${BED_FOLDER}/${GENOME_FILE%.fasta}.10Kb_bins.bed -b ${FREEBAYES_OUTPUT_FOLDER}/${SUBSET} -counts > ${BED_FOLDER}/${SUBSET%.vcf}.var_density.txt")
        	jid46=$(echo $jid46 | sed "s/Submitted batch job //")

	done

done

}

gc_content(){

OUT_GC=${GENOME_FILE%.fasta}_gc_content_density.txt
jid39=$(sbatch --job-name=gc --export=INPUT_FOLDER=${INPUT_FOLDER},GENOME_FILE=${GENOME_FILE},BED_FOLDER=${BED_FOLDER},BED_STEPS=${GENOME_FILE%.fasta}".10Kb_bins.bed",OUTPUT=${OUT_GC} ${SCRIPTS_FOLDER}/gc_content.sh)
jid39=$(echo $jid39 | sed "s/Submitted batch job //")


}
 
main
